﻿/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/
#ifndef __BSP_H__
#define __BSP_H__

/******************************************************************************
 * Includes
 *****************************************************************************/

#include "lpc_types.h"

/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/

#define BSP_ARG2_UART_DATABIT_5 (0)
#define BSP_ARG2_UART_DATABIT_6 (1)
#define BSP_ARG2_UART_DATABIT_7 (2)
#define BSP_ARG2_UART_DATABIT_8 (3)

#define BSP_ARG3_UART_STOPBIT_1 (0)
#define BSP_ARG3_UART_STOPBIT_2 (1)

#define BSP_ARG4_UART_PARITY_NONE (0)
#define BSP_ARG4_UART_PARITY_ODD  (1)
#define BSP_ARG4_UART_PARITY_EVEN (2)

#define BSP_ARG2_SPI_CPHA_FIRST  (0)
#define BSP_ARG2_SPI_CPHA_SECOND (1)

#define BSP_ARG3_SPI_CPOL_HI     (0)
#define BSP_ARG3_SPI_CPOL_LOW    (1)

#define BSP_ARG4_SPI_DATABIT_8    (0)


typedef struct
{
  uint32_t arg1;
  uint32_t arg2;
  uint32_t arg3;
  uint32_t arg4;
} bsp_comm_arg_t;

typedef enum
{
  BSP_COMM_UART = 0,
  BSP_COMM_SPI,
} bsp_comm_t;

/******************************************************************************
 * Public functions
 *****************************************************************************/

void bsp_init(void);
void bsp_rf_init(bsp_comm_t type, bsp_comm_arg_t* args);

void bsp_pinDir(uint8_t pin, uint8_t dir);
void bsp_pinSet(uint8_t pin);
void bsp_pinClr(uint8_t pin);

uint32_t bsp_rf_send(uint8_t *txbuf, uint32_t buflen,
    uint8_t blocking);
uint32_t bsp_rf_sendString(uint8_t *str);
uint32_t bsp_rf_receive(uint8_t *buf, uint32_t buflen);
uint8_t bsp_rf_recvIsEmpty(void);
void bsp_rf_clearRx(void);

uint32_t bsp_rf_spiWriteRead(uint8_t* wrBuf, uint32_t wrLen,
    uint8_t* rdBuf, uint32_t rdLen);

uint32_t bsp_console_sendString(uint8_t *str);
uint32_t bsp_console_send(uint8_t *txbuf, uint32_t buflen,
    uint8_t blocking);
uint32_t bsp_console_receive(uint8_t *buf, uint32_t buflen);

uint32_t bsp_timeGet(void);
void bsp_delayMs(uint32_t ms);
void bsp_delayUs(uint32_t us);

uint8_t bsp_getButtonState(void);
void bsp_setLed(uint8_t on);

#endif
