/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "lpc_types.h"

#include "bsp.h"
#include "eadebug.h"
#include "error.h"
#include "an2500r24a.h"

/******************************************************************************
 * Forward declarations
 *****************************************************************************/


/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/

// RF message IDs
#define RFPT_SET_LED (1)


/******************************************************************************
 * Global Variables
 *****************************************************************************/

// buffer used by eadebug.h
uint8_t g_dbbuf[512];

/******************************************************************************
 * Local Variables
 *****************************************************************************/

static uint8_t rxBuffer[66];

/******************************************************************************
 * Local Functions
 *****************************************************************************/

static void processData(uint8_t* buf, uint8_t len)
{

#ifdef DEBUG
  int i = 0;
  dbg("processData: len=%d\r\n", len);
#endif

  if (len < 3) {
    return;
  }

  // first position is the destionation ID
  dbg("processData: dest=%d\r\n", buf[0]);

  switch (buf[1]) {

  // Set LED request. This is a two byte request where the data
  // indicates if the LED should be turned on or off.
  case RFPT_SET_LED:
    if (len > 1) {
      bsp_setLed(buf[2] != 0);
    }
    break;

  default:
#ifdef DEBUG
    for (i = 0; i < len; i++) {
      if (i > 0 && (i%8) == 0) {
        dbg("\r\n");
      }
      dbg("%x ", buf[i]);
    }
    dbg("\r\n");

#endif
    break;
  }

}


/******************************************************************************
 *
 * Description:
 *   Send a 'set LED' request to destination IP address
 *
 * Params:
 *   [in] ledOn - 1 if LED should be turned on; otherwise 0
 *
 *****************************************************************************/
static error_t sendSetLedRequest(uint8_t ledOn)
{
  uint8_t data[2];

  data[0] = RFPT_SET_LED;
  data[1] = ledOn;

  an2500_send(data, 2, 1);

  return ERR_OK;
}


/******************************************************************************
 * Main method
 *****************************************************************************/

int main (void)
{
  error_t err = ERR_OK;
  uint8_t state = 0;
  uint8_t oldState = 0;

  uint8_t len = 0;

  bsp_init();


  dbg("AN2500R24A demo \r\n");

  err = an2500_init();
  if (err != ERR_OK) {
    dbg("Error: Failed to initialize AN2500\r\n");
    return 0;
  }

  dbg("Initialization successful\r\n");

  while (1) {

    len = an2500_receive(rxBuffer, 66);
    if (len > 0) {
      processData(rxBuffer, len);
    }


    // check button state
    state = bsp_getButtonState();
    if (oldState != state) {
      oldState = state;

      dbg("Button: %d\r\n", state);

      sendSetLedRequest(state);
    }


  }

  return 1;
}



