/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "lpc_types.h"

#include "bsp.h"
#include "eadebug.h"


/******************************************************************************
 * Forward declarations
 *****************************************************************************/

/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/

#define CFG_VAL_RS_220X (0)

/*
 * Application configuration
 *
 *
 * CFG_IS_MODULE_RS220X: Set to 1 if the Redpine Signals RS-XMEGA-220X
 *   module is used; otherwise 0
 *
 */
#define CFG_IS_MODULE_RS220X (1)


/******************************************************************************
 * Global Variables
 *****************************************************************************/

uint8_t g_dbbuf[512];

/******************************************************************************
 * Local Variables
 *****************************************************************************/


/******************************************************************************
 * Local Functions
 *****************************************************************************/

static void powerCycle(void)
{
#if CFG_IS_MODULE_RS220X == 1
  // power enable pin
  bsp_pinDir(11, 1);
  // reset pin
  bsp_pinDir(12, 1);

  // power off
  bsp_pinClr(11);

  // reset and wait 10 ms
  bsp_pinClr(12);
  bsp_delayMs(10);

  // power on
  bsp_pinSet(11);

  // let power stabilize
  bsp_delayMs(20);

  // release reset
  bsp_pinSet(12);

#else
#endif
}

/******************************************************************************
 * Main method
 *****************************************************************************/

int main (void)
{
  uint8_t data;
  uint32_t len;
  bsp_comm_arg_t args;

  bsp_init();

  args.arg1 = 115200;
  args.arg2 = BSP_ARG2_UART_DATABIT_8;
  args.arg4 = BSP_ARG4_UART_PARITY_NONE;

#if CFG_IS_MODULE_RS220X == 1
  args.arg1 = 115200;
  args.arg3 = BSP_ARG3_UART_STOPBIT_2;
  bsp_rf_init(BSP_COMM_UART, &args);
#else
  args.arg1 = 9600;
  args.arg3 = BSP_ARG3_UART_STOPBIT_1;
  bsp_rf_init(BSP_COMM_UART, &args);
#endif

  powerCycle();

  dbg("RF Module Console App\r\n");



  while (1) {

    // get data from RF module and forward to console
    len = bsp_rf_receive(&data, 1);
    if (len > 0) {
      bsp_console_send(&data, 1, 1);
    }

    // get data from console and forward to RF module
    len = bsp_console_receive(&data, 1);
    if (len > 0) {
      bsp_rf_send(&data, 1, 1);
    }

  }

  return 1;
}



