/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "lpc_types.h"

#include "bsp.h"
#include "eadebug.h"

#include "rnxv.h"

/******************************************************************************
 * Forward declarations
 *****************************************************************************/


/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/


/*
 * Application configuration
 *
 *
 * CFG_SSID: The SSID (identifier) of the WLAN network. Must be the same for all
 *   devices on the same network
 *
 */
#define CFG_SSID     ("EAEA")


// RF message IDs
#define RFPT_SET_LED (1)

#define STATE_GET_CMD   (0)
#define STATE_GET_PARAM (1)

/******************************************************************************
 * Global Variables
 *****************************************************************************/

uint8_t g_dbbuf[512];

/******************************************************************************
 * Local Variables
 *****************************************************************************/

/*
 * IP Addresses:
 *
 *  - Make sure the IP addresses are valid and unique on your network.
 *  - If this application is downloaded to more than one board the IP
 *    address must be changed. The same IP address can not be used on
 *    several boards connected to the same network.
 *
 */


static uint8_t ip[4]       = {192,168,5,242};
static uint8_t destIp[4]   = {192,168,5,243};

// network mask
static uint8_t mask[4] = {255,255,255,0};

// the same port number is as destination and source port
static uint16_t commPort   = 0x2616;


static uint8_t appState = STATE_GET_CMD;

/******************************************************************************
 * Local Functions
 *****************************************************************************/


/******************************************************************************
 *
 * Description:
 *   Process received data.
 *
 * Params:
 *   [in] data - one byte of received data
 *
 *****************************************************************************/
static void processData(uint8_t data)
{

  switch (appState) {
  case STATE_GET_CMD:
    if (data == RFPT_SET_LED) {
      appState = STATE_GET_PARAM;
    }
    else {
      dbg("processData: %x (%c)\r\n", data, data);
    }
    break;
  case STATE_GET_PARAM:
    bsp_setLed(data != 0);
    appState = STATE_GET_CMD;
    break;
  }
}

/******************************************************************************
 *
 * Description:
 *   Send a 'set LED' request to destination IP address
 *
 * Params:
 *   [in] ledOn - 1 if LED should be turned on; otherwise 0
 *
 *****************************************************************************/
static error_t sendSetLedRequest(uint8_t ledOn)
{
  uint8_t data[2];

  data[0] = RFPT_SET_LED;
  data[1] = ledOn;

  rnxv_send(data, 2);

  return ERR_OK;
}

/******************************************************************************
 * Main method
 *****************************************************************************/

int main (void)
{
  error_t err = ERR_OK;
  uint8_t state = 0;
  uint8_t oldState = 0;
  uint32_t len = 0;
  uint8_t data;


  bsp_init();

  dbg("RN-XV demo (%d.%d.%d.%d)\r\n", ip[0], ip[1], ip[2], ip[3]);
  dbg(" - Infrastructure\r\n");

  err = rnxv_init((uint8_t*)CFG_SSID, ip, commPort, destIp, commPort, mask);
  if (err != ERR_OK) {
    dbg("Error: Failed to initialize XBee module\r\n");
    return 0;
  }

  dbg("RN-XV initialization successful\r\n");


  while (1) {

    len = rnxv_receive(&data, 1);
    if (len > 0) {
      processData(data);
    }


    // check button state
    state = bsp_getButtonState();
    if (oldState != state) {
      oldState = state;

      dbg("Button: %d\r\n", state);

      sendSetLedRequest(state);
    }


  }

  return 1;
}



