/*****************************************************************************
 *
 *   Copyright(C) 2011, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/
#ifndef __XBEE_S6_H
#define __XBEE_S6_H

/******************************************************************************
 * Includes
 *****************************************************************************/

#include "error.h"

/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/


typedef enum
{
  XBEE_S6_ADHOC_CREATOR = 0,
  XBEE_S6_ADHOC_JOINER,
  XBEE_S6_INFRASTRUCTURE,
} xbeeS6Type_t;

typedef enum
{
  XBEE_S6_TX_STAT_OK = 0,
  XBEE_S6_TX_STAT_PURGED,
  XBEE_S6_TX_STAT_PHY_ERROR,
  XBEE_S6_TX_STAT_TX64_TIMEOUT,
  XBEE_S6_TX_STAT_RCS_ERROR,
  XBEE_S6_TX_STAT_MSG_TOO_LONG,
  XBEE_S6_TX_STAT_SOCK_FAIL,
} xbeeS6TxStatus_t;

typedef enum
{
  XBEE_S6_ENC_WPA = 1,
  XBEE_S6_ENC_WPA2,
  XBEE_S6_ENC_WEP,
} xbeeS6Enc_t;

typedef enum
{
  XBEE_S6_UDP = 0,
  XBEE_S6_TCP,
} xbeeS6Protocol_t;

typedef struct {
  void (*up)(uint8_t up);
  void (*txStat)(uint8_t frameId, xbeeS6TxStatus_t error);
  void (*data)(uint8_t* ip, uint16_t destPort, uint16_t srcPort,
      xbeeS6Protocol_t protocol, uint8_t* buf, uint32_t len);

} xbee_s6_callb_t;

/******************************************************************************
 * Prototypes
 *****************************************************************************/

error_t xbee_s6_init(xbeeS6Type_t type, xbee_s6_callb_t* callbacks,
    uint8_t* ssid, uint8_t channel, uint8_t* ip, uint8_t* mask);

error_t xbee_s6_enableEncryption(xbeeS6Enc_t enc, uint8_t* key);

error_t xbee_s6_send(uint8_t* destIp, uint16_t destPort, uint16_t srcPort,
    xbeeS6Protocol_t protocol, uint8_t* data, uint32_t len, uint8_t* frameId);

void xbee_s6_task(void);

#endif /* end __XBEE_H */



